{
  am_pm_abbreviated => [
    "\N{U+05dc}\N{U+05e4}\N{U+05e0}\N{U+05d4}\N{U+05f4}\N{U+05e6}",
    "\N{U+05d0}\N{U+05d7}\N{U+05d4}\N{U+05f4}\N{U+05e6}",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E H:mm",
    EHms => "E H:mm:ss",
    Ed => "E \N{U+05d4}-d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d \N{U+05d1}MMM y G",
    GyMMMd => "d \N{U+05d1}MMM y G",
    GyMd => "d/M/y GGGGG",
    H => "H",
    Hm => "H:mm",
    Hms => "H:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d.M",
    MMM => "LLL",
    MMMEd => "E, d \N{U+05d1}MMM",
    "MMMMW-count-many" => "\N{U+05e9}\N{U+05d1}\N{U+05d5}\N{U+05e2} W \N{U+05d1}MMMM",
    "MMMMW-count-one" => "\N{U+05e9}\N{U+05d1}\N{U+05d5}\N{U+05e2} W \N{U+05d1}MMMM",
    "MMMMW-count-other" => "\N{U+05e9}\N{U+05d1}\N{U+05d5}\N{U+05e2} W \N{U+05d1}MMMM",
    "MMMMW-count-two" => "\N{U+05e9}\N{U+05d1}\N{U+05d5}\N{U+05e2} W \N{U+05d1}MMMM",
    MMMMd => "d \N{U+05d1}MMMM",
    MMMd => "d \N{U+05d1}MMM",
    Md => "d.M",
    d => "d",
    h => "\N{U+200f}h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E, d.M.y",
    yMM => "M.y",
    yMMM => "MMM y",
    yMMMEd => "E, d \N{U+05d1}MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d \N{U+05d1}MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-many" => "\N{U+05e9}\N{U+05d1}\N{U+05d5}\N{U+05e2} w \N{U+05d1}\N{U+05e9}\N{U+05e0}\N{U+05ea} Y",
    "yw-count-one" => "\N{U+05e9}\N{U+05d1}\N{U+05d5}\N{U+05e2} w \N{U+05d1}\N{U+05e9}\N{U+05e0}\N{U+05ea} Y",
    "yw-count-other" => "\N{U+05e9}\N{U+05d1}\N{U+05d5}\N{U+05e2} w \N{U+05d1}\N{U+05e9}\N{U+05e0}\N{U+05ea} Y",
    "yw-count-two" => "\N{U+05e9}\N{U+05d1}\N{U+05d5}\N{U+05e2} w \N{U+05d1}\N{U+05e9}\N{U+05e0}\N{U+05ea} Y",
  },
  code => "he-IL",
  date_format_full => "EEEE, d \N{U+05d1}MMMM y",
  date_format_long => "d \N{U+05d1}MMMM y",
  date_format_medium => "d \N{U+05d1}MMM y",
  date_format_short => "d.M.y",
  datetime_format_full => "{1} \N{U+05d1}\N{U+05e9}\N{U+05e2}\N{U+05d4} {0}",
  datetime_format_long => "{1} \N{U+05d1}\N{U+05e9}\N{U+05e2}\N{U+05d4} {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05d1}\N{U+05f3}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05d2}\N{U+05f3}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05d3}\N{U+05f3}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05d4}\N{U+05f3}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05d5}\N{U+05f3}",
    "\N{U+05e9}\N{U+05d1}\N{U+05ea}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05d0}\N{U+05f3}",
  ],
  day_format_narrow => [
    "\N{U+05d1}\N{U+05f3}",
    "\N{U+05d2}\N{U+05f3}",
    "\N{U+05d3}\N{U+05f3}",
    "\N{U+05d4}\N{U+05f3}",
    "\N{U+05d5}\N{U+05f3}",
    "\N{U+05e9}\N{U+05f3}",
    "\N{U+05d0}\N{U+05f3}",
  ],
  day_format_wide => [
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05e9}\N{U+05e0}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05e9}\N{U+05dc}\N{U+05d9}\N{U+05e9}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05e8}\N{U+05d1}\N{U+05d9}\N{U+05e2}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05d7}\N{U+05de}\N{U+05d9}\N{U+05e9}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05e9}\N{U+05d9}\N{U+05e9}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05e9}\N{U+05d1}\N{U+05ea}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05e8}\N{U+05d0}\N{U+05e9}\N{U+05d5}\N{U+05df}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05d1}\N{U+05f3}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05d2}\N{U+05f3}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05d3}\N{U+05f3}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05d4}\N{U+05f3}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05d5}\N{U+05f3}",
    "\N{U+05e9}\N{U+05d1}\N{U+05ea}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05d0}\N{U+05f3}",
  ],
  day_stand_alone_narrow => [
    "\N{U+05d1}\N{U+05f3}",
    "\N{U+05d2}\N{U+05f3}",
    "\N{U+05d3}\N{U+05f3}",
    "\N{U+05d4}\N{U+05f3}",
    "\N{U+05d5}\N{U+05f3}",
    "\N{U+05e9}\N{U+05f3}",
    "\N{U+05d0}\N{U+05f3}",
  ],
  day_stand_alone_wide => [
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05e9}\N{U+05e0}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05e9}\N{U+05dc}\N{U+05d9}\N{U+05e9}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05e8}\N{U+05d1}\N{U+05d9}\N{U+05e2}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05d7}\N{U+05de}\N{U+05d9}\N{U+05e9}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05e9}\N{U+05d9}\N{U+05e9}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05e9}\N{U+05d1}\N{U+05ea}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dd} \N{U+05e8}\N{U+05d0}\N{U+05e9}\N{U+05d5}\N{U+05df}",
  ],
  era_abbreviated => [
    "\N{U+05dc}\N{U+05e4}\N{U+05e0}\N{U+05d4}\N{U+05f4}\N{U+05e1}",
    "\N{U+05dc}\N{U+05e1}\N{U+05e4}\N{U+05d9}\N{U+05e8}\N{U+05d4}",
  ],
  era_narrow => [
    "\N{U+05dc}\N{U+05e4}\N{U+05e0}\N{U+05d9}",
    "\N{U+05d0}\N{U+05d7}\N{U+05e8}\N{U+05d9}\N{U+05d9}",
  ],
  era_wide => [
    "\N{U+05dc}\N{U+05e4}\N{U+05e0}\N{U+05d9} \N{U+05d4}\N{U+05e1}\N{U+05e4}\N{U+05d9}\N{U+05e8}\N{U+05d4}",
    "\N{U+05dc}\N{U+05e1}\N{U+05e4}\N{U+05d9}\N{U+05e8}\N{U+05d4}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%Z %H:%M:%S %Y %b %d %a",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%H:%M:%S %Y %b %d %a",
  glibc_time_12_format => "%I:%M:%S %P",
  glibc_time_format => "%H:%M:%S",
  language => "Hebrew",
  month_format_abbreviated => [
    "\N{U+05d9}\N{U+05e0}\N{U+05d5}\N{U+05f3}",
    "\N{U+05e4}\N{U+05d1}\N{U+05e8}\N{U+05f3}",
    "\N{U+05de}\N{U+05e8}\N{U+05e5}",
    "\N{U+05d0}\N{U+05e4}\N{U+05e8}\N{U+05f3}",
    "\N{U+05de}\N{U+05d0}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05e0}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dc}\N{U+05d9}",
    "\N{U+05d0}\N{U+05d5}\N{U+05d2}\N{U+05f3}",
    "\N{U+05e1}\N{U+05e4}\N{U+05d8}\N{U+05f3}",
    "\N{U+05d0}\N{U+05d5}\N{U+05e7}\N{U+05f3}",
    "\N{U+05e0}\N{U+05d5}\N{U+05d1}\N{U+05f3}",
    "\N{U+05d3}\N{U+05e6}\N{U+05de}\N{U+05f3}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "\N{U+05d9}\N{U+05e0}\N{U+05d5}\N{U+05d0}\N{U+05e8}",
    "\N{U+05e4}\N{U+05d1}\N{U+05e8}\N{U+05d5}\N{U+05d0}\N{U+05e8}",
    "\N{U+05de}\N{U+05e8}\N{U+05e5}",
    "\N{U+05d0}\N{U+05e4}\N{U+05e8}\N{U+05d9}\N{U+05dc}",
    "\N{U+05de}\N{U+05d0}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05e0}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dc}\N{U+05d9}",
    "\N{U+05d0}\N{U+05d5}\N{U+05d2}\N{U+05d5}\N{U+05e1}\N{U+05d8}",
    "\N{U+05e1}\N{U+05e4}\N{U+05d8}\N{U+05de}\N{U+05d1}\N{U+05e8}",
    "\N{U+05d0}\N{U+05d5}\N{U+05e7}\N{U+05d8}\N{U+05d5}\N{U+05d1}\N{U+05e8}",
    "\N{U+05e0}\N{U+05d5}\N{U+05d1}\N{U+05de}\N{U+05d1}\N{U+05e8}",
    "\N{U+05d3}\N{U+05e6}\N{U+05de}\N{U+05d1}\N{U+05e8}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+05d9}\N{U+05e0}\N{U+05d5}\N{U+05f3}",
    "\N{U+05e4}\N{U+05d1}\N{U+05e8}\N{U+05f3}",
    "\N{U+05de}\N{U+05e8}\N{U+05e5}",
    "\N{U+05d0}\N{U+05e4}\N{U+05e8}\N{U+05f3}",
    "\N{U+05de}\N{U+05d0}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05e0}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dc}\N{U+05d9}",
    "\N{U+05d0}\N{U+05d5}\N{U+05d2}\N{U+05f3}",
    "\N{U+05e1}\N{U+05e4}\N{U+05d8}\N{U+05f3}",
    "\N{U+05d0}\N{U+05d5}\N{U+05e7}\N{U+05f3}",
    "\N{U+05e0}\N{U+05d5}\N{U+05d1}\N{U+05f3}",
    "\N{U+05d3}\N{U+05e6}\N{U+05de}\N{U+05f3}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "\N{U+05d9}\N{U+05e0}\N{U+05d5}\N{U+05d0}\N{U+05e8}",
    "\N{U+05e4}\N{U+05d1}\N{U+05e8}\N{U+05d5}\N{U+05d0}\N{U+05e8}",
    "\N{U+05de}\N{U+05e8}\N{U+05e5}",
    "\N{U+05d0}\N{U+05e4}\N{U+05e8}\N{U+05d9}\N{U+05dc}",
    "\N{U+05de}\N{U+05d0}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05e0}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dc}\N{U+05d9}",
    "\N{U+05d0}\N{U+05d5}\N{U+05d2}\N{U+05d5}\N{U+05e1}\N{U+05d8}",
    "\N{U+05e1}\N{U+05e4}\N{U+05d8}\N{U+05de}\N{U+05d1}\N{U+05e8}",
    "\N{U+05d0}\N{U+05d5}\N{U+05e7}\N{U+05d8}\N{U+05d5}\N{U+05d1}\N{U+05e8}",
    "\N{U+05e0}\N{U+05d5}\N{U+05d1}\N{U+05de}\N{U+05d1}\N{U+05e8}",
    "\N{U+05d3}\N{U+05e6}\N{U+05de}\N{U+05d1}\N{U+05e8}",
  ],
  name => "Hebrew Israel",
  native_language => "\N{U+05e2}\N{U+05d1}\N{U+05e8}\N{U+05d9}\N{U+05ea}",
  native_name => "\N{U+05e2}\N{U+05d1}\N{U+05e8}\N{U+05d9}\N{U+05ea} \N{U+05d9}\N{U+05e9}\N{U+05e8}\N{U+05d0}\N{U+05dc}",
  native_script => undef,
  native_territory => "\N{U+05d9}\N{U+05e9}\N{U+05e8}\N{U+05d0}\N{U+05dc}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+05e8}\N{U+05d1}\N{U+05e2}\N{U+05d5}\N{U+05df} 1",
    "\N{U+05e8}\N{U+05d1}\N{U+05e2}\N{U+05d5}\N{U+05df} 2",
    "\N{U+05e8}\N{U+05d1}\N{U+05e2}\N{U+05d5}\N{U+05df} 3",
    "\N{U+05e8}\N{U+05d1}\N{U+05e2}\N{U+05d5}\N{U+05df} 4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+05e8}\N{U+05d1}\N{U+05e2}\N{U+05d5}\N{U+05df} 1",
    "\N{U+05e8}\N{U+05d1}\N{U+05e2}\N{U+05d5}\N{U+05df} 2",
    "\N{U+05e8}\N{U+05d1}\N{U+05e2}\N{U+05d5}\N{U+05df} 3",
    "\N{U+05e8}\N{U+05d1}\N{U+05e2}\N{U+05d5}\N{U+05df} 4",
  ],
  script => undef,
  territory => "Israel",
  time_format_full => "H:mm:ss zzzz",
  time_format_long => "H:mm:ss z",
  time_format_medium => "H:mm:ss",
  time_format_short => "H:mm",
  variant => undef,
  version => 41,
}
